@@ -20,12 +20,26 @@
 #ifndef _INFOVIEW_H_
 #define _INFOVIEW_H_
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <glib/gtypes.h>
 #include "procman.h"
 
+typedef struct _Infoview Infoview;
 
+struct _Infoview
+{
+	GtkWidget	*expander;
+	GtkWidget	*box;
+	GtkWidget	*cmd_label;
+	GtkWidget	*status_label;
+	GtkWidget	*nice_label;
+	GtkWidget	*memtotal_label;
+	GtkWidget	*memrss_label;
+	GtkWidget	*memshared_label;
+};
+
+void infoview_create (ProcData *data) G_GNUC_INTERNAL;
+void	infoview_update (ProcData *data) G_GNUC_INTERNAL;
 
-GtkWidget * infoview_create (ProcData *data);
-void	infoview_update (ProcData *data);
 
 #endif
